/* 
 * (c) Copyright IBM Corp. 2005. All Rights Reserved. 
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement. 
 */
package importer;

import java.io.File;

import org.eclipse.jface.dialogs.IDialogPage;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import com.ibm.rational.test.mt.importer.interfaces.IMTAImportSourceConfigSettings;
import com.ibm.rational.test.mt.importer.interfaces.MTANodeKnownProperties;

/**
 *
 * This class creates the import configuration page for the import example.
 */
public class ExampleConfigPage
{
	/**
	 * Wizard Page where the controls created by this instance will be displayed.
	 */
	private IWizardPage page;
	/** 
	 * A container which will display the configuration information.
	 */
	private Composite container;
	
	private Text txtFile;
	
	/**
	 * @see IDialogPage#createControl(Composite)
	 */
	public void createControl( Composite parent ) 
	{
		container = new Composite( parent, SWT.NULL );

		// Add controls to the composite.
		GridLayout gridLayout = new GridLayout( );
		gridLayout.numColumns = 3;
		container.setLayout( gridLayout );
		GridData gd = new GridData( GridData.FILL_HORIZONTAL | GridData.END );
		container.setLayoutData( gd );

		
		// Label
		Label lblImportFile = new Label( container, SWT.NONE );
		lblImportFile.setText( "&Import File:" );
		lblImportFile.setLayoutData( new GridData( GridData.BEGINNING ));

		// Text entry field
		txtFile = new Text( container, SWT.SINGLE );
		GridData data = new GridData( GridData.FILL_HORIZONTAL );
		txtFile.setLayoutData( data );
		txtFile.addModifyListener( new ModifyListener() {
			public void modifyText(ModifyEvent e)
			{
				updateStatus( );
			}
		});
		
		// Browse button
		Button btnBrowse = new Button( container, SWT.PUSH );
		btnBrowse.setText( "&Browse..." );
		data = new GridData( GridData.END );
		btnBrowse.setLayoutData( data );
		btnBrowse.addSelectionListener( new SelectionAdapter( ) {
		 	public void widgetSelected( SelectionEvent e )
		 	{
		 		FileDialog dlg = new FileDialog( container.getShell( ) );
		 		String fileName = dlg.open( );
				if ( fileName != null && !fileName.equals("") )
				{
					txtFile.setText( fileName );
					updateStatus();
				}
		 	}
		 });
		 
		updateStatus( );
	}
	
	/**
	 * Gets the control which has other controls as children
	 * @return
	 */
	protected Control getControl( )
	{
		return container;
	}
	
	/**
	 * Sets the wizard page
	 * @param page
	 */
	protected void setWizardPage( IWizardPage page )
	{
		this.page = page;
		//MESSAGE excel.config.page.title=Configuration Page
		page.setTitle( "Example Configuration Page" );
	}
	
	/**
	 * Adds key value pairs to ConfigSettings object.  This information
	 * will be passed to the implementor.
	 * @param cfgSettings
	 */
	protected void addConfigProperties( IMTAImportSourceConfigSettings cfgSettings )
	{
		String fileName = txtFile.getText();
		cfgSettings.setProperty( MTANodeKnownProperties.PROPERTY_FILESOURCE, fileName );
	}
	
	/**
	 * Updates the page description and button states.
	 * @param msg
	 */
	private void updateStatus( )
	{
		WizardPage wizardPage = (WizardPage) page;
		if ( txtFile.getText().length() > 0 )
		{
			String string = txtFile.getText();
			if ( new File(string).exists() ) 
			{
				wizardPage.setPageComplete( true );
				wizardPage.setErrorMessage( null );
			}
			else
			{
				wizardPage.setPageComplete( false );
				wizardPage.setErrorMessage( "File does not exist" );
			}
		}
		else
		{
			wizardPage.setPageComplete( false );
			wizardPage.setErrorMessage( "Enter a file name" );
		}
	}
}
